==> nextcloud-14.0.1.tgz: nextcloud/apps/systemtags/l10n/fr.js <==
OC.L10N.register(
    "systemtags",
    {
    "Tags" : "Étiquettes",
    "Update" : "Mise à jour",
    "Create" : "Créer",
    "Select tag…" : "Sélectionner une étiquette…",
    "Tagged files" : "Fichiers étiquetés",
    "Select tags to filter by" : "Sélectionner les étiquettes à filtrer",
    "No tags found" : "Aucune étiquette trouvée",
    "Please select tags to filter by" : "Veuillez sélectionner les étiquettes à filtrer",
    "No files found for the selected tags" : "Aucun fichier pour les étiquettes sélectionnées",
    "Added system tag %1$s" : "Étiquette collaborative %1$s ajoutée",
    "Added system tag {systemtag}" : "Étiquette collaborative {systemtag} ajoutée",
    "%1$s added system tag %2$s" : "%1$s a ajouté l'étiquette collaborative %2$s",
    "{actor} added system tag {systemtag}" : "{actor} a ajouté l'étiquette collaborative {systemtag}",
    "Removed system tag %1$s" : "Étiquette collaborative %1$s supprimée",
    "Removed system tag {systemtag}" : "Étiquette collaborative {systemtag} supprimée",
    "%1$s removed system tag %2$s" : "%1$s a supprimé l'étiquette collaborative %2$s",
    "{actor} removed system tag {systemtag}" : "{actor} a supprimé l'étiquette collaborative {systemtag}",
    "You created system tag %1$s" : "Vous avez créé l'étiquette collaborative %1$s",
    "You created system tag {systemtag}" : "Vous avez créé l'étiquette collaborative {systemtag}",
    "%1$s created system tag %2$s" : "%1$s a créé l'étiquette collaborative %2$s",
    "{actor} created system tag {systemtag}" : "{actor} a créé l'étiquette collaborative {systemtag}",
    "You deleted system tag %1$s" : "Vous avez supprimé l'étiquette collaborative %1$s",
    "You deleted system tag {systemtag}" : "Vous avez supprimé l'étiquette collaborative {systemtag}",
    "%1$s deleted system tag %2$s" : "%1$s a supprimé l'étiquette collaborative %2$s",
    "{actor} deleted system tag {systemtag}" : "{actor} a supprimé l'étiquette collaborative {systemtag}",
    "You updated system tag %2$s to %1$s" : "Vous avez renommé l'étiquette collaborative %2$s en %1$s",
    "You updated system tag {oldsystemtag} to {newsystemtag}" : "Vous avez renommé l'étiquette collaborative {oldsystemtag} en {newsystemtag}",
    "%1$s updated system tag %3$s to %2$s" : "%1$s a renommé l'étiquette collaborative %3$s en %2$s",
    "{actor} updated system tag {oldsystemtag} to {newsystemtag}" : "{actor} a renommé l'étiquette collaborative {oldsystemtag} en {newsystemtag}",
    "You added system tag %2$s to %1$s" : "Vous avez ajouté l'étiquette collaborative %2$s à %1$s",
    "You added system tag {systemtag} to {file}" : "Vous avez ajouté l'étiquette collaborative {systemtag} à {file}",
    "%1$s added system tag %3$s to %2$s" : "%1$s a ajouté l'étiquette collaborative %3$s à %2$s",
    "{actor} added system tag {systemtag} to {file}" : "{actor} a ajouté l'étiquette collaborative {systemtag} à {file}",
    "You removed system tag %2$s from %1$s" : "Vous avez retiré l'étiquette collaborative %2$s de %1$s",
    "You removed system tag {systemtag} from {file}" : "Vous avez retiré l'étiquette collaborative {systemtag} de {file}",
    "%1$s removed system tag %3$s from %2$s" : "%1$s a supprimé l'étiquette collaborative %3$s de %2$s",
    "{actor} removed system tag {systemtag} from {file}" : "{actor} a retiré l'étiquette collaborative {systemtag} de {file}",
    "%s (restricted)" : "%s (restreint)",
    "%s (invisible)" : "%s (invisible)",
    "<strong>System tags</strong> for a file have been modified" : "<strong>Les étiquettes collaboratives</strong> pour un fichier ont été modifiées",
    "Collaborative tags" : "Étiquettes collaboratives ",
    "Collaborative tagging functionality which shares tags among users." : "Fonctionnalité de tag collaboratif qui partage les tags entre les utilisateurs.",
    "Collaborative tagging functionality which shares tags among users. Great for teams.\n\t(If you are a provider with a multi-tenancy installation, it is advised to deactivate this app as tags are shared.)" : "Fonctionnalité de tag collaboratif qui partage les tags entre les utilisateurs. Génial pour les équipes.\n\t(Si vous êtes un fournisseur avec plusieurs installations, il est conseillé de désactiver cette application car sinon les tags seront partagés)",
    "Collaborative tags are available for all users. Restricted tags are visible to users but cannot be assigned by them. Invisible tags are for internal use, since users cannot see or assign them." : "Les tags collaboratifs sont disponibles pour tous les utilisateurs. Les tags restreints sont visibles par les utilisateurs mais ne peuvent pas être attribués par eux. Les balises invisibles sont à usage interne, car les utilisateurs ne peuvent pas les voir ou les assigner.",
    "Select tag …" : "Sélectionner une étiquette…",
    "Create a new tag" : "Créer une nouvelle étiquette",
    "Name" : "Nom",
    "Public" : "Public",
    "Restricted" : "Restreint",
    "Invisible" : "Invisible",
    "Delete" : "Supprimer",
    "Reset" : "Réinitialiser",
    "No files in here" : "Aucun fichier",
    "No entries found in this folder" : "Aucune entrée trouvée dans ce dossier",
    "Size" : "Taille",
    "Modified" : "Modifié",
    "Create and edit collaborative tags. These tags affect all users." : "Créer et modifier des étiquettes collaboratives. Ces étiquettes vont affecter tous les utilisateurs."
},
"nplurals=2; plural=(n > 1);");

==> nextcloud-18.0.6.tgz: nextcloud/apps/systemtags/l10n/fr.js <==
OC.L10N.register(
    "systemtags",
    {
    "Tags" : "Étiquettes",
    "Tag name is empty" : "Le nom de l'étiquette est vide",
    "Update" : "Mise à jour",
    "Create" : "Créer",
    "Select tag…" : "Sélectionner une étiquette…",
    "System tag %1$s added by the system" : "L'étiquette système %1$s a été ajoutée par le système.",
    "Added system tag {systemtag}" : "Étiquette collaborative {systemtag} ajoutée",
    "Added system tag %1$s" : "Étiquette collaborative %1$s ajoutée",
    "%1$s added system tag %2$s" : "%1$s a ajouté l'étiquette collaborative %2$s",
    "{actor} added system tag {systemtag}" : "{actor} a ajouté l'étiquette collaborative {systemtag}",
    "System tag %1$s removed by the system" : "L'étiquette système %1$s a été supprimée par le système.",
    "Removed system tag {systemtag}" : "Étiquette collaborative {systemtag} supprimée",
    "Removed system tag %1$s" : "Étiquette collaborative %1$s supprimée",
    "%1$s removed system tag %2$s" : "%1$s a supprimé l'étiquette collaborative %2$s",
    "{actor} removed system tag {systemtag}" : "{actor} a supprimé l'étiquette collaborative {systemtag}",
    "You created system tag %1$s" : "Vous avez créé l'étiquette collaborative %1$s",
    "You created system tag {systemtag}" : "Vous avez créé l'étiquette collaborative {systemtag}",
    "%1$s created system tag %2$s" : "%1$s a créé l'étiquette collaborative %2$s",
    "{actor} created system tag {systemtag}" : "{actor} a créé l'étiquette collaborative {systemtag}",
    "You deleted system tag %1$s" : "Vous avez supprimé l'étiquette collaborative %1$s",
    "You deleted system tag {systemtag}" : "Vous avez supprimé l'étiquette collaborative {systemtag}",
    "%1$s deleted system tag %2$s" : "%1$s a supprimé l'étiquette collaborative %2$s",
    "{actor} deleted system tag {systemtag}" : "{actor} a supprimé l'étiquette collaborative {systemtag}",
    "You updated system tag %2$s to %1$s" : "Vous avez renommé l'étiquette collaborative %2$s en %1$s",
    "You updated system tag {oldsystemtag} to {newsystemtag}" : "Vous avez renommé l'étiquette collaborative {oldsystemtag} en {newsystemtag}",
    "%1$s updated system tag %3$s to %2$s" : "%1$s a renommé l'étiquette collaborative %3$s en %2$s",
    "{actor} updated system tag {oldsystemtag} to {newsystemtag}" : "{actor} a renommé l'étiquette collaborative {oldsystemtag} en {newsystemtag}",
    "System tag %2$s was added to %1$s by the system" : "L'étiquette système %2$s a été ajoutée à %1$s par le système.",
    "System tag {systemtag} was added to {file} by the system" : "L'étiquette système {systemtag} a été ajoutée à {file} par le système",
    "You added system tag %2$s to %1$s" : "Vous avez ajouté l'étiquette collaborative %2$s à %1$s",
    "You added system tag {systemtag} to {file}" : "Vous avez ajouté l'étiquette collaborative {systemtag} à {file}",
    "%1$s added system tag %3$s to %2$s" : "%1$s a ajouté l'étiquette collaborative %3$s à %2$s",
    "{actor} added system tag {systemtag} to {file}" : "{actor} a ajouté l'étiquette collaborative {systemtag} à {file}",
    "System tag %2$s was removed from %1$s by the system" : "L'étiquette système %2$s a été supprimée de %1$s par le système",
    "System tag {systemtag} was removed from {file} by the system" : "L'étiquette système {systemtag} a été supprimée de {file} par le système",
    "You removed system tag %2$s from %1$s" : "Vous avez retiré l'étiquette collaborative %2$s de %1$s",
    "You removed system tag {systemtag} from {file}" : "Vous avez retiré l'étiquette collaborative {systemtag} de {file}",
    "%1$s removed system tag %3$s from %2$s" : "%1$s a supprimé l'étiquette collaborative %3$s de %2$s",
    "{actor} removed system tag {systemtag} from {file}" : "{actor} a retiré l'étiquette collaborative {systemtag} de {file}",
    "%s (restricted)" : "%s (restreint)",
    "%s (invisible)" : "%s (invisible)",
    "<strong>System tags</strong> for a file have been modified" : "<strong>Les étiquettes collaboratives</strong> pour un fichier ont été modifiées",
    "Collaborative tags" : "Étiquettes collaboratives ",
    "Collaborative tagging functionality which shares tags among users." : "Fonctionnalité de tag collaboratif qui partage les tags entre les utilisateurs.",
    "Collaborative tagging functionality which shares tags among users. Great for teams.\n\t(If you are a provider with a multi-tenancy installation, it is advised to deactivate this app as tags are shared.)" : "Fonctionnalité de tag collaboratif qui partage les tags entre les utilisateurs. Génial pour les équipes.\n\t(Si vous êtes un fournisseur avec plusieurs installations, il est conseillé de désactiver cette application car sinon les tags seront partagés)",
    "Tagged files" : "Fichiers étiquetés",
    "Select tags to filter by" : "Indiquez les étiquettes à filtrer",
    "No tags found" : "Aucune étiquette trouvée",
    "Please select tags to filter by" : "Veuillez sélectionner les étiquettes à filtrer",
    "No files found for the selected tags" : "Aucun fichier pour les étiquettes sélectionnées",
    "Collaborative tags are available for all users. Restricted tags are visible to users but cannot be assigned by them. Invisible tags are for internal use, since users cannot see or assign them." : "Les tags collaboratifs sont disponibles pour tous les utilisateurs. Les tags restreints sont visibles par les utilisateurs mais ne peuvent pas être attribués par eux. Les balises invisibles sont à usage interne, car les utilisateurs ne peuvent pas les voir ou les assigner.",
    "Select tag …" : "Sélectionner une étiquette…",
    "Create a new tag" : "Créer une nouvelle étiquette",
    "Name" : "Nom",
    "Public" : "Public",
    "Restricted" : "Restreint",
    "Invisible" : "Invisible",
    "Delete" : "Supprimer",
    "Reset" : "Réinitialiser",
    "No files in here" : "Aucun fichier",
    "No entries found in this folder" : "Aucune entrée trouvée dans ce dossier",
    "Size" : "Taille",
    "Modified" : "Modifié"
},
"nplurals=2; plural=(n > 1);");
